@@ -27,6 +27,8 @@ use List::Util qw/first/;
 use strict;
 use warnings;
 use utf8;
+use App::MtAws::Exceptions;
+use App::MtAws::Utils;
 
 require Exporter;
 use base qw/Exporter/;
@@ -71,7 +73,6 @@ sub new
 	message 'getopts_error', 'Error parsing options', allow_redefine=>1;
 	message 'options_encoding_error', 'Invalid %encoding% character in command line', allow_redefine => 1;
 	message 'config_encoding_error', 'Invalid %encoding% character in config file', allow_redefine => 1;
-	message 'cannot_read_config', "Cannot read config file: %config%", allow_redefine => 1;
 	message 'mandatory', "Option %option a% is mandatory", allow_redefine => 1;
 	message 'positional_mandatory', 'Positional argument #%d n% (%a%) is mandatory', allow_redefine => 1;
 	message 'unexpected_argument', "Unexpected argument in command line: %a%", allow_redefine => 1;
@@ -237,7 +238,7 @@ sub parse_options
 			$cfg_value = $cfg_opt->{default} unless defined $cfg_value;
 			if (defined $cfg_value) { # we should also check that config is 'seen'. we can only check below (so it must be seen)
 				$cfg = $self->read_config($cfg_value);
-				error("cannot_read_config", config => $cfg_value) unless defined $cfg;
+				confess unless defined $cfg;
 			}
 		}
 
@@ -639,21 +640,30 @@ sub warning($;%)
 sub read_config
 {
 	my ($self, $filename) = @_;
-	return unless -f $filename && -r $filename; #TODO test
-	open (my $F, "<:crlf", $filename) || return;
+	-f $filename or
+		die exception 'config_file_is_not_a_file' => "Config file is not a file: %config%",
+		config => hex_dump_string($filename);
+	open (my $F, "<:crlf", $filename) or
+		die exception 'cannot_read_config' => "Cannot read config file: %config%, errno=%errno%",
+		config => hex_dump_string($filename), errno => $!;
 	my %newconfig;
 	local $_;
+	my $lineno = 0;
 	while (<$F>) {
 		chomp;
+		++$lineno;
 		next if /^\s*$/;
 		next if /^\s*\#/;
-		/^([^=]+)=(.*)$/;
-		my ($name, $value) = ($1,$2); # TODO: test lines with wrong format
-		$name =~ s/^[ \t]*//;
-		$name =~ s/[ \t]*$//;
-		$value =~ s/^[ \t]*//;
-		$value =~ s/[ \t]*$//;
-		$newconfig{$name} = $value;
+		my ($name, $value);
+		 # we have there non-unicode data, so [ \t] can be replaced with \s. however i'll leave it for clarity
+		if (($name, $value) = /^[ \t]*([A-Za-z0-9][A-Za-z0-9-]*)[ \t]*=[ \t]*(.*?)[ \t]*$/) {
+			$newconfig{$name} = $value;
+		} elsif (($name) = /^[ \t]*([A-Za-z0-9][A-Za-z0-9-]*)[ \t]*$/) {
+			$newconfig{$name} = 1;
+		} else {
+			die exception 'invalid_config_line' => 'Cannot parse line in config file: %line% at %config% line %lineno%',
+				lineno => $lineno, line => hex_dump_string($_), config => hex_dump_string($filename);
+		}
 	}
 	close $F;
 	return \%newconfig;
