@@ -91,25 +91,31 @@ sub start_children
 		my ($ischild, $child_fromchild, $child_tochild) = $self->create_child($disp_select);
 		if ($ischild) {
 			# child code
+			my $first_time = 1;
+			my @signals = qw/INT TERM USR2 HUP/;
+			for my $sig (@signals) {
+				$SIG{$sig} = sub {
+					if ($first_time) {
+						$first_time = 0;
+						exit(1); # we need exit, it will call all destructors which will destroy tempfiles
+					}
+				}; 
+			}
 			my $C = App::MtAws::ChildWorker->new(options => $self->{options}, fromchild => $child_fromchild, tochild => $child_tochild);
 
-			unless (defined eval {$C->process(); 1;}) {
-				dump_error(q{child});
-				exit(1);
-			}
-			
-			kill(POSIX::SIGUSR1, $parent_pid);
+			dump_error("child $$") unless (defined eval {$C->process(); 1;});
 			exit(1);
 		}
 	}
 	
 	my $first_time = 1;
-	for my $sig (qw/INT TERM CHLD USR1/) {
+	for my $sig (qw/INT TERM CHLD USR1 HUP/) {
 		$SIG{$sig} = sub {
 			local ($!,$^E,$@);
 			if ($first_time) {
 				$first_time = 0;
 				kill (POSIX::SIGUSR2, keys %{$self->{children}});
+				while((my $w = wait()) != -1){};
 				print STDERR "EXIT on SIG$sig\n";
 				exit(1);
 			}
