@@ -24,6 +24,8 @@ use strict;
 use warnings;
 use utf8;
 use base qw/App::MtAws::Job/;
+use Carp;
+use App::MtAws::Utils;
 use File::stat;
 
 
@@ -49,7 +51,9 @@ sub get_task
 		if (scalar @{$self->{archives}}) {
 			my $archive = shift @{$self->{archives}};
 			my $task = App::MtAws::Task->new(id => $archive->{jobid}, action=>"retrieval_download_job", data => {
-				archive_id => $archive->{archive_id}, relfilename => $archive->{relfilename}, filename => $archive->{filename}, mtime => $archive->{mtime}, jobid => $archive->{jobid}
+				archive_id => $archive->{archive_id}, relfilename => $archive->{relfilename},
+				filename => $archive->{filename}, mtime => $archive->{mtime}, jobid => $archive->{jobid},
+				size => $archive->{size}, treehash => $archive->{treehash}
 			});
 			$self->{pending}->{$archive->{jobid}}=1;
 			$self->{all_raised} = 1 unless scalar @{$self->{archives}};
@@ -65,7 +69,7 @@ sub finish_task
 {
 	my ($self, $task) = @_;
 	my $mtime = $task->{data}{mtime};
-	utime $mtime, $mtime, $task->{data}{filename} if defined $mtime; # TODO: is that good that one process writes file and another one change it's mtime?
+	utime $mtime, $mtime, binaryfilename($task->{data}{filename}) or confess if defined $mtime;
 	
 	delete $self->{pending}->{$task->{id}};
 	if ($self->{all_raised} && scalar keys %{$self->{pending}} == 0) {
