@@ -25,10 +25,12 @@ use strict;
 use warnings;
 use utf8;
 use File::Spec;
+use File::stat;
 use Carp;
 use Encode;
 use POSIX;
 use App::MtAws::Exceptions;
+use LWP::UserAgent;
 use bytes;
 no bytes;
 
@@ -38,7 +40,7 @@ use base qw/Exporter/;
 
 our @EXPORT = qw/set_filename_encoding get_filename_encoding binaryfilename
 sanity_relative_filename is_relative_filename open_file sysreadfull syswritefull hex_dump_string
-is_wide_string characterfilename try_drop_utf8_flag/;
+is_wide_string characterfilename try_drop_utf8_flag dump_request_response file_size file_mtime file_exists/;
 
 # Does not work with directory names
 sub sanity_relative_filename
@@ -72,12 +74,12 @@ sub get_filename_encoding() { $_filename_encoding || confess };
 
 sub binaryfilename(;$)
 {
-	encode(get_filename_encoding, @_ ? shift : $_, Encode::DIE_ON_ERR|Encode::LEAVE_SRC);	
+	encode(get_filename_encoding, @_ ? shift : $_, Encode::DIE_ON_ERR|Encode::LEAVE_SRC);
 }
 
 sub characterfilename(;$)
 {
-	decode(get_filename_encoding, @_ ? shift : $_, Encode::DIE_ON_ERR|Encode::LEAVE_SRC);	
+	decode(get_filename_encoding, @_ ? shift : $_, Encode::DIE_ON_ERR|Encode::LEAVE_SRC);
 }
 
 =pod
@@ -107,41 +109,41 @@ sub open_file($$%)
 	(undef, my $filename, my %args) = @_;
 	%args = (use_filename_encoding => 1, %args);
 	my $original_filename = $filename;
-	
+
 	my %checkargs = %args;
 	defined $checkargs{$_} && delete $checkargs{$_} for qw/use_filename_encoding mode file_encoding not_empty binary/;
 	confess "Unknown argument(s) to open_file: ".join(';', keys %checkargs) if %checkargs;
-	
+
 	confess 'Argument "mode" is required' unless defined($args{mode});
 	confess "unknown mode $args{mode}" unless $args{mode} =~ m!^\+?(<|>>?)$!;
 	my $mode = $args{mode};
-	
+
 	confess "not_empty can be used in read mode only"
 		if ($args{not_empty} && $args{mode} ne '<');
-		
-	
+
+
 	if (defined($args{file_encoding})) {
 		$mode .= ":encoding($args{file_encoding})";
 		confess "cannot use binary and file_encoding at same time'" if $args{binary};
 	} elsif (!$args{binary}) {
 		confess "there should be file encoding or 'binary'";
 	}
-	
+
 	if ($args{use_filename_encoding}) {
 		$filename = binaryfilename $filename;
 	}
-	
+
 	confess "File is not a plain file" if -e $filename && (! -f $filename);
 	confess "File should not be empty" if $args{not_empty} && (! -s $filename);
-	
+
 	open ($_[0], $mode, $filename) or return;
 	my $f = $_[0];
-	
+
 	confess unless -f $f; # check for race condition - it was a file when we last checked, but now it's a directory
 	confess if $args{not_empty} && (! -s $f);
-	
+
 	binmode $f if $args{binary};
-	
+
 	return $f;
 }
 
@@ -152,17 +154,38 @@ sub file_size($%)
 	if ($args{use_filename_encoding}) {
 		$filename = binaryfilename $filename;
 	}
-	croak unless -f $filename;
+	confess "file not exists" unless -f $filename;
 	return -s $filename;
 }
 
+sub file_exists($%)
+{
+	my $filename = shift;
+	my (%args) = (use_filename_encoding => 1, @_);
+	if ($args{use_filename_encoding}) {
+		$filename = binaryfilename $filename;
+	}
+	return -f $filename;
+}
+
+sub file_mtime($%)
+{
+	my $filename = shift;
+	my (%args) = (use_filename_encoding => 1, @_);
+	if ($args{use_filename_encoding}) {
+		$filename = binaryfilename $filename;
+	}
+	confess "file not exists" unless -f $filename;
+	return stat($filename)->mtime;
+}
+
 sub is_wide_string
 {
 	defined($_[0]) && utf8::is_utf8($_[0]) && (bytes::length($_[0]) != length($_[0]))
 }
 
 # if we have ASCII-only data, let's drop UTF-8 flag in order to optimize some regexp stuff
-# TODO: write also version which does not check is_utf8 - it's faster when utf8 always set 
+# TODO: write also version which does not check is_utf8 - it's faster when utf8 always set
 sub try_drop_utf8_flag
 {
 	Encode::_utf8_off($_[0]) if utf8::is_utf8($_[0]) && (bytes::length($_[0]) == length($_[0]));
@@ -223,6 +246,35 @@ sub hex_dump_string
 	$str;
 }
 
+sub dump_request_response
+{
+	my ($req, $resp) = @_;
+	my $out = '';
+	$out .= "===REQUEST:\n";
+	$out .= join(" ", $req->method, $req->uri)."\n";
+
+	my $req_headers = $req->headers->as_string;
+
+	$req_headers =~ s!^(Authorization:.*Credential=)([A-Za-z0-9]+)/!$1***REMOVED***/!;
+	$req_headers =~ s!^(Authorization:.*Signature=)([A-Za-z0-9]+)!$1***REMOVED***!;
+
+	$out .= $req_headers;
+
+	if ($req->content_type ne 'application/octet-stream' && $req->content && length($req->content)) {
+		$out .= "\n".$req->content;
+	}
+
+	$out .= "\n===RESPONSE:\n";
+	$out .= $resp->protocol." " if $resp->protocol;
+	$out .= $resp->status_line."\n";
+	$out .= $resp->headers->as_string;
+
+	if ($resp->content_type eq 'application/json' && $resp->content && length($resp->content)) {
+		$out .= "\n".$resp->content;
+	}
+	$out .= "\n\n";
+	$out;
+}
 
 1;
 
